Reads 'Agilent' .dx files.
Arguments
- path
Path to Agilent
.dxfile.- what
Whether to extract chromatograms (
chroms), DAD data (dad) and/or auxiliary instrumental data (instrument) (e.g., temperature, pressure, solvent composition, etc.). Accepts multiple arguments.- path_out
A directory to export unzipped files. If a path is not specified, the files will be written to a temp directory on the disk. The function will overwrite existing folders in the specified directory that share the basename of the file specified by
path.- format_out
Class of output. Either
matrix,data.frame, ordata.table.- data_format
Whether to return data in
wide(default) orlongformat.- read_metadata
Logical. Whether to attach metadata. Defaults to
TRUE.- metadata_format
Format to output metadata. Either
chromconverterorraw.- collapse
Logical. Whether to collapse lists that only contain a single element. Defaults to
TRUE.
Details
This function unzips 'Agilent' .dx into a temporary directory using
unzip and calls the appropriate parser on the unzipped file.
See also
Other 'Agilent' parsers:
read_agilent_d(),
read_chemstation_ch(),
read_chemstation_csv(),
read_chemstation_ms(),
read_chemstation_reports(),
read_chemstation_uv()