Reads 'Agilent Chemstation' .csv files.
Usage
read_chemstation_csv(
path,
format_out = "matrix",
data_format = "wide",
read_metadata = TRUE
)Arguments
- path
Path to 'Agilent'
.csvfile.- format_out
Class of output. Either
matrix,data.frame, ordata.table.- data_format
Whether to return data in
wide(default) orlongformat.- read_metadata
Logical. Whether to attach metadata. Defaults to
TRUE. There is no instrumental metadata saved in the CSV files so this will only attach metadata about the settings used by chromConverter to parse the file.
See also
Other 'Agilent' parsers:
read_agilent_d(),
read_agilent_dx(),
read_chemstation_ch(),
read_chemstation_ms(),
read_chemstation_reports(),
read_chemstation_uv()