Reads 'Thermo Fisher Chromeleon™ CDS' ASCII (.txt) files.
read_chromeleon(
path,
format_out = c("matrix", "data.frame", "data.table"),
data_format = c("wide", "long"),
read_metadata = TRUE,
metadata_format = c("chromconverter", "raw"),
decimal_mark = NULL
)A chromatogram in the format specified by format_out.
(retention time x wavelength).
Path to 'Chromeleon' ASCII file.
Class of output. Either matrix, data.frame,
or data.table.
Whether to return data in wide or long format.
Whether to read metadata from file.
Format to output metadata. Either chromconverter or
raw.
Which character is used as the decimal separator in the
file. By default, decimal mark will be detected automatically, but it can
also be manually set as "." or ",".
Ethan Bass