Reads 'Lumex' .mdf files.
read_mdf(
path,
format_out = c("matrix", "data.frame", "data.table"),
data_format = c("wide", "long"),
read_metadata = TRUE
)A chromatogram in the format specified by the format_out and
data_format arguments (retention time x wavelength).
The path to a 'Lumex' .mdf file.
Class of output. Either matrix, data.frame,
or data.table.
Whether to return data in wide or long format.
Whether to read metadata from file.
Ethan Bass