Skip to contents

Converts a single chromatogram from MassHunter .sp format to R data.frame using the Aston file parser.

Usage

sp_converter(
  path,
  format_out = c("matrix", "data.frame", "data.table"),
  data_format = c("wide", "long"),
  read_metadata = TRUE,
  metadata_format = c("chromconverter", "raw")
)

Arguments

path

Path to file.

format_out

Class of output. Either matrix, data.frame, or data.table.

data_format

Whether to return data in wide (default) or long format.

read_metadata

Logical. Whether to attach metadata. Defaults to TRUE.

metadata_format

Format to output metadata. Either chromconverter (standardized field names) or raw (vendor field names, unmapped).

Value

A chromatogram in the format specified by the format_out and data_format arguments.

Deprecation

The 'aston' parser is deprecated and will be removed in a future release. 'Aston' has been unmaintained since 2020. This is the only remaining 'aston' binding, and read_chroms selects it automatically only as a last resort, when no other parser can read the file. Please use the 'entab' parser (by the same author as 'Aston') instead, e.g. read_chroms(path, format_in = "masshunter_dad", parser = "entab").