Uses rainbow parsers to read in Agilent (.D)
and Waters (.raw) files. If format_in is "agilent_d" or
"waters_raw", a directory of the appropriate format (.d or
.raw) should be provided to the file argument. If format_in is
"chemstation_uv" a .uv file should be provided. Data can be filtered
by detector type using the what argument.
call_rainbow(
path,
format_in = c("agilent_d", "waters_raw", "masshunter", "chemstation", "chemstation_uv",
"chemstation_fid"),
format_out = c("matrix", "data.frame", "data.table"),
data_format = c("wide", "long"),
by = c("detector", "name"),
what = NULL,
read_metadata = TRUE,
metadata_format = c("chromconverter", "raw"),
collapse = TRUE,
precision = 1
)Returns a (nested) list of matrices or data.frames according to
the value of format_out. Data is ordered according to the value of
by.
Path to file.
Format of the supplied files. Either agilent_d,
waters_raw, or chemstation.
R format. Either matrix, data.frame, or
data.table.
Whether to return data in wide or long format.
How to order the list that is returned. Either detector
(default) or name.
What types of data to return (e.g. MS, UV, CAD,
ELSD). This argument only applies if by == "detector".
Logical. Whether to attach metadata. Defaults to TRUE.
Format to output metadata. Either chromconverter
or raw.
Logical. Whether to collapse lists that only contain a single element.
Number of decimals to round mz values. Defaults to 1.
Ethan Bass
Other external parsers:
call_entab(),
call_openchrom(),
read_thermoraw(),
sp_converter(),
uv_converter()