Extracts injection metadata from 'Agilent Common Analytical Markup Language' (ACAML) files into an R object.
Usage
read_acaml(
path,
find_files,
format_out = c("data.frame", "data.table", "tibble"),
progress_bar = TRUE,
cl = 1
)Arguments
- path
Path(s) to ACAML files or to folders that contain the files.
- find_files
Logical. Set to
TRUE(default) if you are providing the function with a folder or vector of folders containing the files. Otherwise, set toFALSE.- format_out
Class of output. Either
matrix,data.frame, ordata.table.- progress_bar
Logical. Whether to show progress bar. Defaults to
TRUEifpbapplyis installed.- cl
Argument to pbapply specifying the number of clusters to use or a cluster object created by makeCluster. Defaults to
1.