Extracts injection metadata from 'Agilent Common Analytical Markup Language'
(ACAML) files into a data.frame.
Usage
read_acaml(
paths,
find_files,
format_out = c("data.frame", "data.table", "tibble"),
progress_bar = TRUE,
cl = 1
)Arguments
- paths
Paths to ACAML files or to folders that contain the files.
- find_files
Logical. Set to
TRUE(default) if you are providing the function with a folder or vector of folders containing the files. Otherwise, set toFALSE.- format_out
Either
data.frame,data.table, ortibble.- progress_bar
Logical. Whether to show progress bar. Defaults to
TRUEifpbapplyis installed.- cl
Argument to
pbapplyspecifying the number of clusters to use or a cluster object created bymakeCluster. Defaults to1.