Reads files from 'Agilent' .D directories.
Arguments
- path
Path to 'Agilent'
.Ddirectory.- what
Whether to extract chromatograms (
chroms), DAD data (dad) and/or peak tables (peak_table). Accepts multiple arguments.- format_out
Class of output. Either
matrix,data.frame, ordata.table.- data_format
Whether to return data in
wide(default) orlongformat.- read_metadata
Logical. Whether to attach metadata. Defaults to
TRUE.- metadata_format
Format to output metadata. Either
chromconverterorraw.- collapse
Logical. Whether to collapse lists that only contain a single element. Defaults to
TRUE.
Value
A list of chromatograms in the format specified by data_format and
format_out. If data_format is wide, the chromatograms will be
returned with retention times as rows and columns containing signal intensity
for each signal. If long format is requested, retention times will be
in the first column. The format_out argument determines whether the
chromatogram is returned as a matrix, data.frame or data.table.
Metadata can be attached to the chromatogram as attributes if
read_metadata is TRUE.
See also
Other 'Agilent' parsers:
read_agilent_dx(),
read_chemstation_ch(),
read_chemstation_csv(),
read_chemstation_ms(),
read_chemstation_reports(),
read_chemstation_uv()