Reads 'Allotrope Simple Model' files into R.
Arguments
- path
Path to ASM
.jsonfile.- data_format
Whether to return data in
wide(default) orlongformat.- format_out
Class of output. Either
matrix,data.frame, ordata.table.- read_metadata
Logical. Whether to attach metadata. Defaults to
TRUE.- metadata_format
Format to output metadata. Either
chromconverterorraw.- collapse
Logical. Whether to collapse lists that only contain a single element. Defaults to
TRUE.
Value
A 2D chromatogram in the format specified by data_format and
format_out. If data_format is wide, the chromatogram will be returned
with retention times as rows and a single column for the intensity. If long
format is requested, two columns will be returned: one for the
retention time and one for the intensity. The format_out argument
determines whether the chromatogram is returned as a matrix, data.frame,
or data.table. Metadata can be attached to the chromatogram as attributes
if read_metadata is TRUE.