Reads 'Agilent ChemStation MSD Spectral Files' beginning with
x01/x32/x00/x00.
Arguments
- path
Path to 'Agilent'
.msfile.- what
Which streams to return:
MS1,BPCand/orTIC. Defaults to all three.- format_out
Class of output. Either
matrix,data.frame, ordata.table.- data_format
Whether to return the
BPCandTICinlong(default) orwideformat. Mass spectra are always returned inlongformat.- read_metadata
Logical. Whether to attach metadata. Defaults to
TRUE.- metadata_format
Format to output metadata. Either
chromconverter(standardized field names) orraw(vendor field names, unmapped).- collapse
Logical. Whether to collapse lists that only contain a single element. Defaults to
TRUE.
Value
A list of the streams in what, in the format specified by
format_out. In wide format, the BPC and TIC have retention times as
rows and a single intensity column; in long format, a retention time column
and an intensity column. MS data will always be returned in long format. The
format_out argument determines whether the chromatogram is returned as a
matrix, data.frame, or data.table. Metadata are attached as attributes if
read_metadata is TRUE. With collapse = TRUE, a list of one stream is
replaced by that stream.
Note
Many thanks to Evan Shi and Eugene Kwan for providing helpful information on the structure of these files in the rainbow documentation.