Reads 'Agilent ChemStation MSD Spectral Files' beginning with
x01/x32/x00/x00.
Arguments
- path
Path to 'Agilent'
.msfile.- what
What stream to get: current options are
MS1,BPCand/orTIC. If a stream is not specified, the function will return all streams.- format_out
Class of output. Either
matrix,data.frame, ordata.table.- data_format
Whether to return data in
wide(default) orlongformat.- read_metadata
Logical. Whether to attach metadata. Defaults to
TRUE.- metadata_format
Format to output metadata. Either
chromconverterorraw.- collapse
Logical. Whether to collapse lists that only contain a single element. Defaults to
TRUE.
Value
A list of chromatograms in the format specified by data_format and
format_out. If data_format is wide, 2D chromatograms will
be returned with retention times as rows and a single column for the
intensity. Otherwise, two columns will be returned: one for the
retention time and one for the intensity. MS data will always be returned in
long format. The format_out argument determines whether the chromatogram is
returned as a matrix, data.frame, or data.table. Metadata can be
attached to the chromatogram as attributes if read_metadata is TRUE.
Note
Many thanks to Evan Shi and Eugene Kwan for providing helpful information on the structure of these files in the rainbow documentation.
See also
Other 'Agilent' parsers:
read_agilent_d(),
read_agilent_dx(),
read_chemstation_ch(),
read_chemstation_csv(),
read_chemstation_reports(),
read_chemstation_uv()