Reads 'Agilent ChemStation MSD Spectral Files' beginning with
x01/x32/x00/x00.
read_chemstation_ms(
path,
what = c("MS1", "BPC", "TIC"),
format_out = c("matrix", "data.frame", "data.table"),
data_format = c("wide", "long"),
read_metadata = TRUE,
metadata_format = c("chromconverter", "raw"),
collapse = TRUE
)A 2D chromatogram in the format specified by data_format and
format_out. If data_format is wide, the chromatogram will
be returned with retention times as rows and a single column for the intensity.
If long format is requested, two columns will be returned: one for the
retention time and one for the intensity. The format_out argument
determines whether the chromatogram is returned as a matrix,
data.frame, or data.table. Metadata can be attached to the
chromatogram as attributes if read_metadata is TRUE.
Path to 'Agilent' .ms file.
What stream to get: current options are MS1, BPC
and/or TIC. If a stream is not specified, the function will return all
streams.
Class of output. Either matrix, data.frame,
or data.table.
Whether to return data in wide or long format.
Logical. Whether to attach metadata. Defaults to TRUE.
Format to output metadata. Either chromconverter
or raw.
Logical. Whether to collapse lists that only contain a single
element. Defaults to TRUE.
Ethan Bass
Other 'Agilent' parsers:
read_agilent_d(),
read_agilent_dx(),
read_chemstation_ch(),
read_chemstation_csv(),
read_chemstation_reports(),
read_chemstation_uv()
if (FALSE) {
read_chemstation_ms(path)
}
Run the code above in your browser using DataLab