Agilent .uv files come in several different formats. This parser can
automatically detect and read several versions of these files from
'Agilent ChemStation' and 'Agilent OpenLab', including versions 31 and
131.
read_chemstation_uv(
path,
format_out = c("matrix", "data.frame", "data.table"),
data_format = c("wide", "long"),
read_metadata = TRUE,
metadata_format = c("chromconverter", "raw"),
scale = TRUE
)A 3D chromatogram in the format specified by data_format and
format_out. If data_format is wide, the chromatogram will
be returned with retention times as rows and wavelengths as columns. If
long format is requested, three columns will be returned: one for the
retention time, one for the wavelength and one for the intensity. The
format_out argument determines whether the chromatogram is returned as
a matrix or data.frame. Metadata can be attached to the
chromatogram as attributes if read_metadata is TRUE.
Path to 'Agilent' .uv file.
Class of output. Either matrix, data.frame,
or data.table.
Either wide (default) or long.
Logical. Whether to attach metadata. Defaults to TRUE.
Format to output metadata. Either chromconverter
or raw.
Whether to scale the data by the scaling factor present in the
file. Defaults to TRUE.
Ethan Bass
Other 'Agilent' parsers:
read_agilent_d(),
read_agilent_dx(),
read_chemstation_ch(),
read_chemstation_csv(),
read_chemstation_ms(),
read_chemstation_reports()
if (FALSE) { # interactive()
read_chemstation_uv("tests/testthat/testdata/dad1.uv")
}
Run the code above in your browser using DataLab