Reads chromatograms from specified folders or vector of paths using either an internal parser or bindings to an external library, such as Aston, Entab, ThermoRawFileParser, OpenChrom, rainbow.
Usage
read_chroms(
paths,
format_in = c("agilent_d", "agilent_dx", "asm", "chemstation", "chemstation_fid",
"chemstation_ch", "chemstation_csv", "chemstation_ms", "chemstation_uv",
"masshunter_dad", "chromeleon_uv", "chromatotec", "mzml", "mzxml", "mdf",
"shimadzu_ascii", "shimadzu_dad", "shimadzu_fid", "shimadzu_gcd", "shimadzu_qgd",
"shimadzu_lcd", "thermoraw", "varian_sms", "waters_arw", "waters_raw", "msd", "csd",
"wsd", "csv", "other"),
find_files,
pattern = NULL,
parser = c("", "chromconverter", "aston", "entab", "thermoraw", "openchrom", "rainbow"),
format_out = c("matrix", "data.frame", "data.table"),
data_format = c("wide", "long"),
path_out = NULL,
export_format = c("", "csv", "chemstation_csv", "cdf", "mzml", "animl", "arw"),
force = FALSE,
read_metadata = TRUE,
metadata_format = c("chromconverter", "raw"),
progress_bar,
cl = 1,
verbose = getOption("verbose"),
sample_names = c("basename", "sample_name"),
dat = NULL,
...
)Arguments
- paths
Paths to data files or directories containing the files.
- format_in
Format of files to be imported/converted. Current options include:
agilent_d,agilent_dx,chemstation,chemstation_uv,chemstation_ch,chemstation_csv,chemstation_ms,masshunter,masshunter_dad,chromeleon_uv,shimadzu_ascii,shimadzu_fid,shimadzu_dad,thermoraw,waters_arw,waters_raw,mzml,mzxml,cdf,mdf,msd,csd,wsd, orother.- find_files
Logical. Set to
TRUE(default) if you are providing the function with a folder or vector of folders containing the files. Otherwise, set toFALSE.- pattern
pattern (e.g. a file extension). Defaults to
NULL, in which case file extension will be deduced fromformat_in.- parser
What parser to use (optional). Current option are
chromconverter,aston,,entab,thermoraw,openchrom,rainbow.- format_out
Class of output. Either
matrix,data.frame, ordata.table.- data_format
Whether to output data in wide or long format. Either
wide(default) orlong.- path_out
Path for exporting files. If path is not specified, the user will be prompted to create a temp directory.
- export_format
Export format. Currently the options include
.csv,chemstation_csv(utf-16 encoding),cdf,mzml,animlandarw.- force
Logical. Whether to overwrite files when exporting. Defaults to
FALSE.- read_metadata
Logical, whether to attach metadata (if it's available). Defaults to
TRUE.- metadata_format
Format to output metadata. Either
chromconverterorraw.- progress_bar
Logical. Whether to show progress bar. Defaults to
TRUEifpbapplyis installed.- cl
Argument to pbapply specifying the number of clusters to use or a cluster object created by makeCluster. Defaults to
1.- verbose
Logical. Whether to print output from external parsers to the R console.
- sample_names
Which sample names to use. Options are
basenameto use the filename (default) orsample_nameto use the sample name encoded in the file metadata.- dat
Existing list of chromatograms to append results. Defaults to
NULL.- ...
Additional arguments to parser.
Value
A list of chromatograms in matrix, data.frame, or data.table
format, according to the value of format_out. Chromatograms may be returned
in either wide or long format according to the value of data_format.
Details
Provides a unified interface to all chromConverter parsers. Currently recognizes
'Agilent ChemStation' (.uv, .ch, .dx), 'Agilent MassHunter' (.dad),
'Thermo RAW' (.raw), 'Waters ARW' (.arw), 'Waters RAW' (.raw),
'Chromeleon ASCII' (.txt), 'Shimadzu ASCII' (.txt),
'Shimadzu GCD' (.gcd), 'Shimadzu LCD' (.lcd, DAD and chromatogram streams)
and 'Shimadzu QGD' (.qgd) files. Also, wraps 'OpenChrom' parsers, which
include many additional formats. To use 'Entab', 'ThermoRawFileParser', or
'OpenChrom' parsers, they must be separately installed. Please see the
instructions in the README
for further details.
If paths to individual files are provided, read_chroms will try to
infer the file format and select an appropriate parser. However, when
providing paths to directories, the file format must be specified using the
format_in argument.