Reads peak lists from specified folders or vector of paths.
Usage
read_peaklist(
paths,
find_files,
format_in = c("chemstation", "shimadzu_fid", "shimadzu_dad", "shimadzu_lcd",
"shimadzu_gcd", "chromatotec", "asm"),
pattern = NULL,
peaktable_format = c("chromatographr", "original"),
metadata_format = c("chromconverter", "raw"),
read_metadata = TRUE,
progress_bar,
cl = 1,
data_format = NULL
)Arguments
- paths
Paths to files or folders containing peak list files.
- find_files
Logical. Whether to treat the supplied paths as directories to search for files. Inferred if not supplied, by testing whether every path is a file.
- format_in
Format of files to be imported/converted. One of
chemstation(the default),shimadzu_fid,shimadzu_dad,shimadzu_lcd,shimadzu_gcd,chromatotec, orasm.- pattern
A pattern (e.g. a file extension). Defaults to
NULL, in which case the file extension will be deduced fromformat_in.- peaktable_format
Whether to return peak tables in
chromatographrororiginalformat.- metadata_format
Format to output metadata. Either
chromconverter(standardized field names) orraw(vendor field names, unmapped).- read_metadata
Logical. Whether to attach metadata. Defaults to
TRUE.- progress_bar
Logical. Whether to show progress bar. Defaults to
TRUEifpbapplyis installed.- cl
Argument to pbapply specifying the number of parallel workers to use or a cluster object created by makeCluster (a set of parallel R worker processes). Defaults to
1.- data_format
Deprecated. Use
peaktable_formatinstead.