Reads peak lists from specified folders or vector of paths.
Arguments
- paths
Paths to files or folders containing peak list files.
- find_files
Logical. Set to
TRUE(default) if you are providing the function with a folder or vector of folders containing the files. Otherwise, set toFALSE.- format_in
Format of files to be imported/converted. Current options include:
chemstation,shimadzu_fid,shimadzu_dad,shimadzu_lcd, andshimadzu_gcd.- pattern
pattern (e.g. a file extension). Defaults to
NULL, in which case the file extension will be deduced fromformat_in.- data_format
Either
chromatographrororiginal.- metadata_format
Format to output metadata. Either
chromconverterorraw.- read_metadata
Logical, whether to attach metadata (if it's available). Defaults to
TRUE.- progress_bar
Logical. Whether to show progress bar. Defaults to
TRUEifpbapplyis installed.- cl
Argument to
pbapplyspecifying the number of clusters to use or a cluster object created bymakeCluster. Defaults to1.