Reads 'Shimadzu' ASCII (.txt) files. These files can be exported from
'Shimadzu LabSolutions' by right clicking on samples in the sample list and
selecting File Conversion:Convert to ASCII.
read_shimadzu(
path,
what = "chroms",
format_in = NULL,
include = c("fid", "lc", "dad", "uv", "tic"),
format_out = c("matrix", "data.frame"),
data_format = c("wide", "long"),
peaktable_format = c("chromatographr", "original"),
read_metadata = TRUE,
metadata_format = c("chromconverter", "raw"),
ms_format = c("data.frame", "list"),
collapse = TRUE,
scale = TRUE
)A nested list of elements from the specified file, where the
top levels are chromatograms, peak tables, and/or mass spectra according to
the value of what. Chromatograms are returned in the format specified
by format_out (retention time x wavelength).
Path to Shimadzu .txt ASCII file.
Whether to extract chromatograms (chroms),
peak_table, and/or ms_spectra. Accepts multiple arguments.
This argument is deprecated and is no longer required.
Which chromatograms to include. Options are fid,
dad, uv, tic, and status.
R format. Either matrix or data.frame.
Whether to return data in wide or long format.
Whether to return peak tables in chromatographr
or original format.
Whether to read metadata from file.
Format to output metadata. Either chromconverter
or raw.
Whether to return mass spectral data as a (long)
data.frame or a list.
Logical. Whether to collapse lists that only contain a single element.
Whether to scale the data by the scaling factor present in the
file. Defaults to TRUE.
Ethan Bass
Other 'Shimadzu' parsers:
read_shimadzu_gcd(),
read_shimadzu_lcd(),
read_shimadzu_qgd(),
read_sz_lcd_2d(),
read_sz_lcd_3d()
if (FALSE) { # interactive()
path <- "tests/testthat/testdata/ladder.txt"
read_shimadzu(path)
}
Run the code above in your browser using DataLab