Converts a single chromatogram from MassHunter .sp format to R
data.frame using the Aston file parser.
Arguments
- path
Path to file.
- format_out
Class of output. Either
matrix,data.frame, ordata.table.- data_format
Whether to return data in
wide(default) orlongformat.- read_metadata
Logical. Whether to attach metadata. Defaults to
TRUE.- metadata_format
Format to output metadata. Either
chromconverter(standardized field names) orraw(vendor field names, unmapped).
Deprecation
The 'aston' parser is deprecated and will be removed in a future release.
'Aston' has been unmaintained since 2020. This is the only remaining 'aston'
binding, and read_chroms selects it automatically only as a last resort,
when no other parser can read the file. Please use the 'entab' parser (by
the same author as 'Aston') instead, e.g.
read_chroms(path, format_in = "masshunter_dad", parser = "entab").
See also
Other external parsers:
call_entab(),
call_openchrom(),
call_rainbow(),
read_thermoraw(),
uv_converter()