Writes chromatograms to disk in the format specified by export_format:
either (mzml), cdf or csv.
write_chroms(
chrom_list,
path_out,
export_format = c("mzml", "cdf", "csv"),
what = "",
force = FALSE,
show_progress = TRUE,
verbose = getOption("verbose"),
...
)No return value. The function is called for its side effects.
A list of chromatograms.
Path to directory for writing files.
Format to export files: either mzml, cdf,
or csv.
What to write. Either MS1 or chrom.
Logical. Whether to overwrite existing files. Defaults to TRUE.
Logical. Whether to show progress bar. Defaults to TRUE.
Logical. Whether to print verbose output.
Additional arguments to write function.
Exports a chromatogram in the file format specified by export_format
in the directory specified by path_out.
Ethan Bass
Other write functions:
write_andi_chrom(),
write_mzml()